#
# spec file for package zvbi
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         sover 0
%define         libname lib%{name}%{sover}
%define         libchains lib%{name}-chains%{sover}
Name:           zvbi
Version:        0.2.35
Release:        lp150.2.5
Summary:        Linux "VBI proxy"
License:        LGPL-2.1+ AND GPL-2.0+
Group:          Productivity/Multimedia/Other
Url:            http://zapping.sf.net/
Source:         https://sourceforge.net/projects/zapping/files/zvbi/%{version}/zvbi-%{version}.tar.bz2
Source2:        baselibs.conf
Patch00:        00_fix-configure.in.patch
Patch01:        01_Makefile.am.patch
Patch03:        03_fails-to-write.patch
Patch05:        05_MAXPATHLEN.patch
Patch06:        06_sizeof-FTBFS.patch
Patch07:        07_fix-spelling-in-binaries.patch
Patch08:        08_fix-manpage.patch
Patch09:        09_fix-FTBFS-GCC6.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  timezone
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(x11)
Recommends:     %{name}-lang

%description
With "video4linux" drivers, only one application at a time can capture
VB data.  The 2nd generation "v4l2" API allows multiple clients to
open a device, but still only one client may read from the device.  If,
for example, the Nxtvepg daemon runs in the background, users will not be
able to start a Teletext application.  The VBI proxy was developed as a
solution to this problem.

%package -n %{libname}
Summary:        VBI Decoding Library
Group:          System/Libraries

%description -n %{libname}
VBI stands for Vertical Blanking Interval, a gap between the image data
transmitted in an analog video signal. This gap is used to transmit AM
modulated data for various data services like Teletext and Closed
Caption.

The zvbi library provides routines to read from raw VBI sampling
devices, to demodulate raw to sliced VBI data, and to interpret the
data of several popular services.

%package -n %{libchains}
Summary:        VBI Decoding Library
Group:          System/Libraries
Conflicts:      %{libname} < %{version}-%{release}

%description -n %{libchains}
VBI stands for Vertical Blanking Interval, a gap between the image data
transmitted in an analog video signal. This gap is used to transmit AM
modulated data for various data services like Teletext and Closed
Caption.

The zvbi library provides routines to read from raw VBI sampling
devices, to demodulate raw to sliced VBI data, and to interpret the
data of several popular services.

%package devel
Summary:        Development files for the VBI decoding library
Group:          Development/Libraries/C and C++
Requires:       %{libchains} = %{version}
Requires:       %{libname} = %{version}

%description devel
This package includes the development files for the zvbi library which
provides routines to read from raw VBI sampling devices, to demodulate raw to
sliced VBI data, and to interpret the data of several popular services.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch3 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1

%build
ACLOCAL="aclocal -I m4" autoreconf -fi
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}

%check
# This requires timezone package to be installed
make %{?_smp_mflags} check

%post -n %{libname} -p /sbin/ldconfig
%post -n %{libchains} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig
%postun -n %{libchains} -p /sbin/ldconfig

%files
%doc AUTHORS BUGS COPYING ChangeLog NEWS README TODO
%{_bindir}/zvbi-atsc-cc
%{_bindir}/zvbi-chains
%{_bindir}/zvbi-ntsc-cc
%{_sbindir}/zvbid
%{_mandir}/man1/zvbi-atsc-cc.1%{ext_man}
%{_mandir}/man1/zvbi-chains.1%{ext_man}
%{_mandir}/man1/zvbi-ntsc-cc.1%{ext_man}
%{_mandir}/man1/zvbid.1%{ext_man}

%files lang -f %{name}.lang

%files -n %{libname}
%{_libdir}/libzvbi.so.%{sover}*

%files -n %{libchains}
%{_libdir}/libzvbi-chains.so.%{sover}*

%files devel
%{_includedir}/libzvbi.h
%{_libdir}/libzvbi.so
%{_libdir}/libzvbi-chains.so
%{_libdir}/pkgconfig/zvbi-*.pc

%changelog
* Mon Dec 11 2017 jengelh@inai.de
- Update RPM groups and descriptions.
* Wed Dec  6 2017 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add dropped dependency for libICE
- Add dependency for libpng support
- Split lang subpackage
- Split library subpackages
- Use patches from debian:
  * 00_fix-configure.in.patch
  * 01_Makefile.am.patch
  * 03_fails-to-write.patch
  * 05_MAXPATHLEN.patch
  * 06_sizeof-FTBFS.patch
  * 07_fix-spelling-in-binaries.patch
  * 08_fix-manpage.patch
  * 09_fix-FTBFS-GCC6.patch
- Drop zvbi-automake-1.13.patch
- Enable tests
- Use url for source
* Tue Dec  5 2017 crrodriguez@opensuse.org
- BuildRequire pkgconfig(x11) instead of xorg-x11-devel
* Tue Sep 24 2013 stephan.barth@suse.com
- update to version 0.2.35 which includes numerous fixes that are listed in
  the ChangeLog
- added upstream ChangeLog to the package
- removed fix-headers.patch because it is included in upstream now
- added an fdupes call for the documentation files in the devel package
* Wed Mar 13 2013 pgajdos@suse.cz
- builds with automake 1.13
  * automake-1.13.patch
* Mon Aug 27 2012 cfarrell@suse.com
- license update: LGPL-2.1+ and GPL-2.0+
  Use SPDX format and include the LGPL as well
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Sep 16 2011 jengelh@medozas.de
- Implement baselibs.conf for package
- Remove redundant tags/sections; remove author list (encoding
  screwed up and no longer used in factory)
* Mon Jun  6 2011 aj@suse.de
- Add missing includes for <sys/stat.h>
* Thu Sep 11 2008 mmarek@suse.cz
- updated to 0.2.33
  * includes zvbi-0.2.32-atsc-cc-include.patch
* Wed Sep  3 2008 mmarek@suse.cz
- updated to 0.2.32
  * This version adds a new tool named zvbi-atsc-cc to record
    Closed Caption from ATSC digital TV. It supports legacy NTSC
    caption (EIA 608-B) and DTVCC (CEA 708-C).
* Mon Jul 28 2008 mmarek@suse.cz
- updated to 0.2.31
  * The vbi_caption_unicode() function did not correctly translate
    the small letter i with diaresis.
  * The files daemon/chains.c, daemon/proxyd.c,
    test/proxy-test.c and test/cc-test-stream.dtd are now licensed
    under GPLv2 or later as stated in the top README file.
    (fixes bnc#408881)
* Fri Jul  4 2008 mmarek@suse.cz
- updated to 0.2.30
  * The ZVBI libraries libzvbi and libzvbi-chains are now licensed
    under the terms of the GNU Library General Public License
    version 2 or later.  Example programs are now licensed under a
    2-clause BSD-style license. The VBI proxy daemon, contributed
    programs, test programs and programs required to build the
    library remain licensed under GNU General Public License
    version 2 or later.
  * The VTX export module has been disabled for licensing reasons.
    It may return after a rewrite.
  * New BCD functions and vbi_ham24p(), counterpart of
    vbi_unham24p(), were added.
  * The artificial 41st column in Teletext pages is no longer black
    but continues the previous column if appropriate.
  * The --default-cs option of the export test tool now works with
    libzvbi 0.2 as well.
  * bugfixes
- split the library package into libzvbi0, updated package
  descriptions
* Mon Feb  4 2008 mmarek@suse.cz
- updated to 0.2.26
  * new program zvbi-ntsc-cc: ntsc-cc Closed Caption decoder from
    the Xawtv package using libzvbi for driver access and bit
    slicing.
  * support for raw VBI capturing with unknown field order
  * lots of other enhancements and bugfixes
- don't install static libraries and *.la files
* Fri Aug 31 2007 mmarek@suse.cz
- fixed build with new glibc
- specfile cleanup
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Wed Jul 27 2005 kraxel@suse.de
- update to version 0.2.16.
* Mon Jan 24 2005 kraxel@suse.de
- update to version 0.2.13.
* Tue Jan 11 2005 kraxel@suse.de
- build fix: doygen needs libpng.
* Wed Jan  5 2005 kraxel@suse.de
- fix documentation build.
* Tue Jan  4 2005 kraxel@suse.de
- update to version 0.2.11
* Tue Jun  8 2004 kraxel@suse.de
- update to version 0.2.8
* Wed Feb 11 2004 kraxel@suse.de
- update to version 0.2.5
* Sun Nov  9 2003 adrian@suse.de
- add %%run_ldconfig
* Thu Jun 19 2003 ro@suse.de
- build with current gettext
* Tue May 27 2003 ro@suse.de
- add .la file to devel file list
* Mon Feb 17 2003 kraxel@suse.de
- updated to version 0.2.4 (adds v4l2 support)
* Fri Jan 17 2003 kraxel@suse.de
- fixed spec to make the package build on older distributions too.
* Tue Jan 14 2003 kraxel@suse.de
- updated to version 0.2.3
* Mon Nov 18 2002 schwab@suse.de
- Add AM_GNU_GETTEXT_VERSION.
* Wed Nov 13 2002 kraxel@suse.de
- updated to version 0.2.2
* Mon Nov 11 2002 ro@suse.de
- use x-devel-packages in neededforbuild
* Mon Jun 17 2002 kraxel@suse.de
- updated to version 0.2.1
* Tue Apr 30 2002 kraxel@suse.de
- fixed lib64 build problems.
* Thu Apr 11 2002 kraxel@suse.de
- initial release.
